==> postcss-image-inliner-3.0.0.tgz: package/index.js <==
const postcss = require('postcss');
const debug = require('debug')('image-inliner');
const last = require('lodash/last');
const escapeRegExp = require('lodash/escapeRegExp');
const {getDataUriMapping} = require('./lib/image');

const DEFAULTS = {
  assetPaths: [],
  maxFileSize: 10240,
  b64Svg: false,
  strict: false
};

const loop = cb => {
  const matcher = /url\(\s*(?:['"]*)(?!['"]*data:)(.*?)(?:['"]*)\s*\)/gm;
  return decl => {
    let match;
    while ((match = matcher.exec(decl.value)) !== null) {
      cb({decl, url: last(match)});
    }
  };
};

module.exports = postcss.plugin('postcss-image-inliner', (opts = {}) => {
  const options = {...DEFAULTS, ...opts};

  if (Array.isArray(options.assetPaths)) {
    options.assetPaths = [...options.assetPaths, process.cwd()];
  } else {
    options.assetPaths = [options.assetPaths, process.cwd()];
  }

  return async css => {
    const urls = new Set([]);
    const filter = /^(background(?:-image)?)|(content)|(cursor)/;
    // Get urls
    css.walkDecls(filter, loop(({url}) => urls.add(url)));

    const mapping = await getDataUriMapping([...urls], options);

    css.walkDecls(
      filter,
      loop(({decl, url}) => {
        if (mapping[url]) {
          const regexp = new RegExp('[\'"]?' + escapeRegExp(url) + '[\'"]?', 'gm');
          if (url.startsWith('//')) {
            //       Console.log({url, regexp, val: decl.value});
          }

          decl.value = decl.value.replace(regexp, '\'' + mapping[url] + '\'');
          if (url.startsWith('//')) {
            //       Console.log('RESULT: ', decl.value);
          }

          debug(url, 'successfully replaced with ', mapping[url]);
        } else {
          debug(url, 'failed');
          if (opts.strict) {
            throw new Error('No file found for ' + url);
          }
        }
      })
    );
  };
});

==> postcss-image-inliner-3.0.3.tgz: package/index.js <==
'use strict';

const postcss = require('postcss');
const debug = require('debug')('image-inliner');
const last = require('lodash/last');
const escapeRegExp = require('lodash/escapeRegExp');
const {getDataUriMapping} = require('./lib/image');

const DEFAULTS = {
  assetPaths: [],
  maxFileSize: 10240,
  b64Svg: false,
  strict: false
};

const loop = cb => {
  const matcher = /url\(\s*(?:['"]*)(?!['"]*data:)(.*?)(?:['"]*)\s*\)/gm;
  return decl => {
    let match;
    while ((match = matcher.exec(decl.value)) !== null) {
      cb({decl, url: last(match)});
    }
  };
};

module.exports = postcss.plugin('postcss-image-inliner', (opts = {}) => {
  const options = {...DEFAULTS, ...opts};

  if (Array.isArray(options.assetPaths)) {
    options.assetPaths = [...options.assetPaths, process.cwd()];
  } else {
    options.assetPaths = [options.assetPaths, process.cwd()];
  }

  return async css => {
    const urls = new Set([]);
    const filter = /^(background(?:-image)?)|(content)|(cursor)/;
    // Get urls
    css.walkDecls(filter, loop(({url}) => urls.add(url)));

    const mapping = await getDataUriMapping([...urls], options);

    css.walkDecls(
      filter,
      loop(({decl, url}) => {
        if (mapping[url]) {
          const regexp = new RegExp(`['"]?${escapeRegExp(url)}['"]?`, 'gm');

          decl.value = decl.value.replace(regexp, `'${mapping[url]}'`);
          debug(url, 'successfully replaced with ', mapping[url]);
        } else {
          debug(url, 'failed');
          if (opts.strict) {
            throw new Error(`No file found for ${url}`);
          }
        }
      })
    );
  };
});
